@@ -25,10 +25,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QDragEnterEvent>
 #include <QHeaderView>
 #include <QTreeView>
+#include <QDir>
+#include <QMimeData>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KLocale>
+#include <KUrlMimeData>
 
 // Local
 #include <lib/contextmanager.h>
@@ -41,7 +43,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <lib/placetreemodel.h>
 #define MODEL_CLASS PlaceTreeModel
 #else
-#include <KDirLister>
 #include <lib/semanticinfo/sorteddirmodel.h>
 #define MODEL_CLASS SortedDirModel
 #endif
@@ -90,13 +91,13 @@ protected:
 
     void dropEvent(QDropEvent* event)
     {
-        const KUrl::List urlList = KUrl::List::fromMimeData(event->mimeData());
+        const QList<QUrl> urlList = KUrlMimeData::urlsFromMimeData(event->mimeData());
         const QModelIndex index = indexAt(event->pos());
         if (!index.isValid()) {
-            kWarning() << "Invalid index!";
+            qWarning() << "Invalid index!";
             return;
         }
-        const KUrl destUrl = static_cast<MODEL_CLASS*>(model())->urlForIndex(index);
+        const QUrl destUrl = static_cast<MODEL_CLASS*>(model())->urlForIndex(index);
         FileOperations::showMenuForDroppedUrls(this, urlList, destUrl);
     }
 
@@ -110,7 +111,7 @@ struct FolderViewContextManagerItemPrivate
     MODEL_CLASS* mModel;
     QTreeView* mView;
 
-    KUrl mUrlToSelect;
+    QUrl mUrlToSelect;
     QPersistentModelIndex mExpandingIndex;
 
     void setupModel()
@@ -121,10 +122,9 @@ struct FolderViewContextManagerItemPrivate
         for (int col = 1; col <= mModel->columnCount(); ++col) {
             mView->header()->setSectionHidden(col, true);
         }
-        mModel->dirLister()->openUrl(KUrl("/"));
+        mModel->dirLister()->openUrl(QUrl("/"));
 #endif
-        QObject::connect(mModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-                         q, SLOT(slotRowsInserted(QModelIndex,int,int)));
+        QObject::connect(mModel, &MODEL_CLASS::rowsInserted, q, &FolderViewContextManagerItem::slotRowsInserted);
     }
 
     void setupView()
@@ -150,12 +150,11 @@ struct FolderViewContextManagerItemPrivate
         mView->header()->setResizeMode(QHeaderView::ResizeToContents);
 
         q->setWidget(mView);
-        QObject::connect(mView, SIGNAL(activated(QModelIndex)),
-                         q, SLOT(slotActivated(QModelIndex)));
+        QObject::connect(mView, &QTreeView::activated, q, &FolderViewContextManagerItem::slotActivated);
         EventWatcher::install(mView, QEvent::Show, q, SLOT(expandToSelectedUrl()));
     }
 
-    QModelIndex findClosestIndex(const QModelIndex& parent, const KUrl& wantedUrl)
+    QModelIndex findClosestIndex(const QModelIndex& parent, const QUrl &wantedUrl)
     {
         Q_ASSERT(mModel);
         QModelIndex index = parent;
@@ -166,16 +165,15 @@ struct FolderViewContextManagerItemPrivate
             }
         }
 
-        bool isParent;
-        KUrl url = mModel->urlForIndex(index);
-        QString relativePath = KUrl::relativePath(url.path(), wantedUrl.path(), &isParent);
-        if (!isParent) {
-            kWarning() << url << "is not a parent of" << wantedUrl << "!";
+        QUrl url = mModel->urlForIndex(index);
+        if (!url.isParentOf(wantedUrl)) {
+            qWarning() << url << "is not a parent of" << wantedUrl << "!";
             return QModelIndex();
         }
 
+        QString relativePath = QDir(url.path()).relativeFilePath(wantedUrl.path());
         QModelIndex lastFoundIndex = index;
-        Q_FOREACH(const QString & pathPart, relativePath.mid(1).split('/', QString::SkipEmptyParts)) {
+        Q_FOREACH(const QString & pathPart, relativePath.split(QDir::separator(), QString::SkipEmptyParts)) {
             bool found = false;
             for (int row = 0; row < mModel->rowCount(lastFoundIndex); ++row) {
                 QModelIndex index = mModel->index(row, 0, lastFoundIndex);
@@ -193,13 +191,13 @@ struct FolderViewContextManagerItemPrivate
         return lastFoundIndex;
     }
 
-    QModelIndex findRootIndex(const KUrl& wantedUrl)
+    QModelIndex findRootIndex(const QUrl &wantedUrl)
     {
         QModelIndex matchIndex;
         int matchUrlLength = 0;
         for (int row = 0; row < mModel->rowCount(); ++row) {
             QModelIndex index = mModel->index(row, 0);
-            KUrl url = mModel->urlForIndex(index);
+            QUrl url = mModel->urlForIndex(index);
             int urlLength = url.url().length();
             if (url.isParentOf(wantedUrl) && urlLength > matchUrlLength) {
                 matchIndex = index;
@@ -207,7 +205,7 @@ struct FolderViewContextManagerItemPrivate
             }
         }
         if (!matchIndex.isValid()) {
-            kWarning() << "Found no root index for" << wantedUrl;
+            qWarning() << "Found no root index for" << wantedUrl;
         }
         return matchIndex;
     }
@@ -222,8 +220,8 @@ FolderViewContextManagerItem::FolderViewContextManagerItem(ContextManager* manag
 
     d->setupView();
 
-    connect(contextManager(), SIGNAL(currentDirUrlChanged(KUrl)),
-            SLOT(slotCurrentDirUrlChanged(KUrl)));
+    connect(contextManager(), SIGNAL(currentDirUrlChanged(QUrl)),
+            SLOT(slotCurrentDirUrlChanged(QUrl)));
 }
 
 FolderViewContextManagerItem::~FolderViewContextManagerItem()
@@ -231,12 +229,11 @@ FolderViewContextManagerItem::~FolderViewContextManagerItem()
     delete d;
 }
 
-void FolderViewContextManagerItem::slotCurrentDirUrlChanged(const KUrl& url)
+void FolderViewContextManagerItem::slotCurrentDirUrlChanged(const QUrl &url)
 {
     if (url.isValid() && d->mUrlToSelect != url) {
-        d->mUrlToSelect = url;
-        d->mUrlToSelect.cleanPath();
-        d->mUrlToSelect.adjustPath(KUrl::RemoveTrailingSlash);
+        d->mUrlToSelect = QDir::cleanPath(url.path());
+        d->mUrlToSelect = d->mUrlToSelect.adjusted(QUrl::StripTrailingSlash);
         d->mExpandingIndex = QModelIndex();
     }
     if (!d->mView->isVisible()) {
@@ -262,13 +259,13 @@ void FolderViewContextManagerItem::expandToSelectedUrl()
     }
     d->mExpandingIndex = index;
 
-    KUrl url = d->mModel->urlForIndex(d->mExpandingIndex);
+    QUrl url = d->mModel->urlForIndex(d->mExpandingIndex);
     if (d->mUrlToSelect == url) {
         // We found our url
         QItemSelectionModel* selModel = d->mView->selectionModel();
         selModel->setCurrentIndex(d->mExpandingIndex, QItemSelectionModel::ClearAndSelect);
         d->mView->scrollTo(d->mExpandingIndex);
-        d->mUrlToSelect = KUrl();
+        d->mUrlToSelect = QUrl();
         d->mExpandingIndex = QModelIndex();
     } else {
         // We found a parent of our url
@@ -295,7 +292,7 @@ void FolderViewContextManagerItem::slotActivated(const QModelIndex& index)
         return;
     }
 
-    KUrl url = d->mModel->urlForIndex(index);
+    QUrl url = d->mModel->urlForIndex(index);
     emit urlChanged(url);
 }
 
