@@ -19,28 +19,24 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "documentview.moc"
+#include "documentview.h"
 
 // Qt
-#include <QAbstractScrollArea>
 #include <QApplication>
 #include <QGraphicsLinearLayout>
 #include <QGraphicsProxyWidget>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsSceneWheelEvent>
-#include <QMouseEvent>
 #include <QPainter>
 #include <QPropertyAnimation>
-#include <QScrollBar>
-#include <QVBoxLayout>
 #include <QWeakPointer>
+#include <QDebug>
+#include <QIcon>
+#include <QUrl>
 
 // KDE
-#include <KDebug>
-#include <KIcon>
-#include <KLocale>
-#include <KUrl>
+#include <KLocalizedString>
 
 // Local
 #include <lib/document/document.h>
@@ -68,7 +64,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) //qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -146,7 +142,11 @@ struct DocumentViewPrivate
         q->adapterChanged();
         q->positionChanged();
         if (adapter->canZoom()) {
-            q->zoomToFitChanged(adapter->zoomToFit());
+            if (adapter->zoomToFit()) {
+                q->zoomToFitChanged(true);
+            } else {
+                q->zoomChanged(adapter->zoom());
+            }
         }
         if (adapter->rasterImageView()) {
             QObject::connect(adapter->rasterImageView(), SIGNAL(currentToolChanged(AbstractRasterImageViewTool*)),
@@ -169,7 +169,7 @@ struct DocumentViewPrivate
         } else {
             button->setToolTip(text);
         }
-        button->setIcon(KIcon(iconName));
+        button->setIcon(QIcon::fromTheme(iconName));
         return button;
     }
 
@@ -369,7 +369,7 @@ void DocumentView::createAdapterForDocument()
         static_cast<MessageViewAdapter*>(adapter)->setErrorMessage(i18n("Gwenview does not know how to display this kind of document"));
         break;
     default:
-        kWarning() << "should not be called for documentKind=" << documentKind;
+        qWarning() << "should not be called for documentKind=" << documentKind;
         adapter = new MessageViewAdapter;
         break;
     }
@@ -377,7 +377,7 @@ void DocumentView::createAdapterForDocument()
     d->setCurrentAdapter(adapter);
 }
 
-void DocumentView::openUrl(const KUrl& url, const DocumentView::Setup& setup)
+void DocumentView::openUrl(const QUrl &url, const DocumentView::Setup& setup)
 {
     if (d->mDocument) {
         if (url == d->mDocument->url()) {
@@ -387,7 +387,7 @@ void DocumentView::openUrl(const KUrl& url, const DocumentView::Setup& setup)
     }
     d->mSetup = setup;
     d->mDocument = DocumentFactory::instance()->load(url);
-    connect(d->mDocument.data(), SIGNAL(busyChanged(KUrl,bool)), SLOT(slotBusyChanged(KUrl,bool)));
+    connect(d->mDocument.data(), SIGNAL(busyChanged(QUrl,bool)), SLOT(slotBusyChanged(QUrl,bool)));
 
     if (d->mDocument->loadingState() < Document::KindDetermined) {
         MessageViewAdapter* messageViewAdapter = qobject_cast<MessageViewAdapter*>(d->mAdapter.data());
@@ -395,7 +395,7 @@ void DocumentView::openUrl(const KUrl& url, const DocumentView::Setup& setup)
             messageViewAdapter->setInfoMessage(QString());
         }
         d->showLoadingIndicator();
-        connect(d->mDocument.data(), SIGNAL(kindDetermined(KUrl)),
+        connect(d->mDocument.data(), SIGNAL(kindDetermined(QUrl)),
                 SLOT(finishOpenUrl()));
     } else {
         QMetaObject::invokeMethod(this, "finishOpenUrl", Qt::QueuedConnection);
@@ -405,7 +405,7 @@ void DocumentView::openUrl(const KUrl& url, const DocumentView::Setup& setup)
 
 void DocumentView::finishOpenUrl()
 {
-    disconnect(d->mDocument.data(), SIGNAL(kindDetermined(KUrl)),
+    disconnect(d->mDocument.data(), SIGNAL(kindDetermined(QUrl)),
                this, SLOT(finishOpenUrl()));
     GV_RETURN_IF_FAIL(d->mDocument->loadingState() >= Document::KindDetermined);
 
@@ -415,7 +415,7 @@ void DocumentView::finishOpenUrl()
     }
     createAdapterForDocument();
 
-    connect(d->mDocument.data(), SIGNAL(loadingFailed(KUrl)),
+    connect(d->mDocument.data(), SIGNAL(loadingFailed(QUrl)),
             SLOT(slotLoadingFailed()));
     d->mAdapter->setDocument(d->mDocument);
     d->updateCaption();
@@ -464,7 +464,7 @@ void DocumentView::slotLoadingFailed()
     d->hideLoadingIndicator();
     MessageViewAdapter* adapter = new MessageViewAdapter;
     adapter->setDocument(d->mDocument);
-    QString message = i18n("Loading <filename>%1</filename> failed", d->mDocument->url().fileName());
+    QString message = xi18n("Loading <filename>%1</filename> failed", d->mDocument->url().fileName());
     adapter->setErrorMessage(message, d->mDocument->errorString());
     d->setCurrentAdapter(adapter);
     emit completed();
@@ -603,7 +603,7 @@ void DocumentView::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*op
     }
 }
 
-void DocumentView::slotBusyChanged(const KUrl&, bool busy)
+void DocumentView::slotBusyChanged(const QUrl&, bool busy)
 {
     if (busy) {
         d->showLoadingIndicator();
@@ -660,10 +660,10 @@ Document::Ptr DocumentView::document() const
     return d->mDocument;
 }
 
-KUrl DocumentView::url() const
+QUrl DocumentView::url() const
 {
     Document::Ptr doc = d->mDocument;
-    return doc ? doc->url() : KUrl();
+    return doc ? doc->url() : QUrl();
 }
 
 void DocumentView::emitHudDeselectClicked()
